aboutsummaryrefslogtreecommitdiff
path: root/src/lua/jin.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/lua/jin.cpp')
-rw-r--r--src/lua/jin.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/lua/jin.cpp b/src/lua/jin.cpp
index e6d0a2a..fc1e443 100644
--- a/src/lua/jin.cpp
+++ b/src/lua/jin.cpp
@@ -2,9 +2,9 @@
#include "lua/modules/luax.h"
#include "embed/embed.h"
-namespace jin
+namespace JinEngine
{
-namespace lua
+namespace Lua
{
extern int luaopen_core(lua_State* L);
@@ -102,8 +102,8 @@ namespace lua
void boot(lua_State* L)
{
- jin::embed::boot(L);
+ JinEngine::embed::boot(L);
}
-} // lua
-} // jin \ No newline at end of file
+} // Lua
+} // JinEngine \ No newline at end of file